"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WeekNumberFlag = exports.ChevronFlag = exports.CalendarFlag = exports.DayModifier = exports.UI = void 0;
/**
 * The UI elements composing DayPicker. These elements are mapped to
 * {@link CustomComponents}, the {@link ClassNames} and the {@link Styles} used by
 * DayPicker.
 */
var UI;
(function (UI) {
    /** The previous button in the navigation. */
    UI["ButtonPrevious"] = "button_previous";
    /** The next button the navigation */
    UI["ButtonNext"] = "button_next";
    /**
     * The calendar element: the root component displaying the months and the
     * navigation bar. Extended by {@link CalendarFlag}.
     */
    UI["Calendar"] = "calendar";
    /** The Chevron SVG element used by navigation buttons and dropdowns. */
    UI["Chevron"] = "chevron";
    /** The grid cell with the day's date. Extended by {@link DayModifier}. */
    UI["Day"] = "day";
    /** The element containing the formatted day's date, inside the grid cell. */
    UI["DayDate"] = "day_date";
    /** The caption label of the month (when not showing the dropdown navigation). */
    UI["CaptionLabel"] = "caption_label";
    /** The container of the dropdown navigation (when enabled). */
    UI["DropdownNav"] = "dropdown_nav";
    /** The dropdown element to select for years and months. */
    UI["Dropdown"] = "dropdown";
    /** The container element of the dropdown. */
    UI["DropdownRoot"] = "dropdown_root";
    /** The root element of the footer. */
    UI["Footer"] = "footer";
    /** The month grid. */
    UI["Month"] = "month";
    /** Contains the dropdown navigation or the caption label. */
    UI["MonthCaption"] = "month_caption";
    /** The dropdown with the months. */
    UI["MonthsDropdown"] = "months_dropdown";
    /** Wrapper of the {@link} grid. */
    UI["MonthWrapper"] = "month_wrapper";
    /** The container of the displayed months. */
    UI["Months"] = "months";
    /** The navigation bar with the previous and next buttons */
    UI["Nav"] = "nav";
    /** The row containing the week. */
    UI["Week"] = "week";
    /** The group of row weeks in a month. */
    UI["Weeks"] = "weeks";
    /** The column header with the weekday. */
    UI["Weekday"] = "weekday";
    /** The row grouping the weekdays in the column headers. */
    UI["Weekdays"] = "weekdays";
    /**
     * The row header containing the week number. Extended by
     * {@link WeekNumberFlag}.
     */
    UI["WeekNumber"] = "week_number";
    /** The dropdown with the years. */
    UI["YearsDropdown"] = "years_dropdown";
})(UI || (exports.UI = UI = {}));
/** The modifiers for the {@link UI.Day}. */
var DayModifier;
(function (DayModifier) {
    /** The day is disabled */
    DayModifier["disabled"] = "disabled";
    /** The day is hidden */
    DayModifier["hidden"] = "hidden";
    /** The day is outside the current month */
    DayModifier["outside"] = "outside";
    /** The day is at the end of a selected range. */
    DayModifier["range_end"] = "range_end";
    /** The day is at the middle of a selected range. */
    DayModifier["range_middle"] = "range_middle";
    /** The day is at the start of a selected range. */
    DayModifier["range_start"] = "range_start";
    /** The day is selected. */
    DayModifier["selected"] = "selected";
    /** The day is focusable. */
    DayModifier["focusable"] = "focusable";
    /** The day is focused. */
    DayModifier["focused"] = "focused";
    /** The day is today. */
    DayModifier["today"] = "today";
})(DayModifier || (exports.DayModifier = DayModifier = {}));
/** Flags that can be applied to the {@link UI.Calendar} element. */
var CalendarFlag;
(function (CalendarFlag) {
    /** Assigned when the week numbers are show. */
    CalendarFlag["hasWeekNumbers"] = "has_week_numbers";
    /** Assigned when the weekdays are hidden. */
    CalendarFlag["noWeekdays"] = "no_weekdays";
    /** Assigned when the calendar has multiple months. */
    CalendarFlag["hasMultipleMonths"] = "has_multiple_months";
})(CalendarFlag || (exports.CalendarFlag = CalendarFlag = {}));
/** Flags that can be applied to the {@link UI.Chevron} element. */
var ChevronFlag;
(function (ChevronFlag) {
    /** Assigned when the week numbers are show. */
    ChevronFlag["disabled"] = "chevron_disabled";
})(ChevronFlag || (exports.ChevronFlag = ChevronFlag = {}));
/** Flags that can be applied to the {@link UI.WeekNumber} element. */
var WeekNumberFlag;
(function (WeekNumberFlag) {
    /**
     * Assigned when the week number is interactive, i.e. has an
     * `onWeekNumberClick` event attached to it.
     */
    WeekNumberFlag["isInteractive"] = "week_number_interactive";
})(WeekNumberFlag || (exports.WeekNumberFlag = WeekNumberFlag = {}));
//# sourceMappingURL=UI.js.map