"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Calendar = void 0;
const react_1 = __importDefault(require("react"));
const UI_1 = require("../UI");
const calendar_1 = require("../contexts/calendar");
const props_1 = require("../contexts/props");
const Footer_1 = require("./Footer");
const Month_1 = require("./Month");
const Months_1 = require("./Months");
const Nav_1 = require("./Nav");
/**
 * Render the DayPicker Calendar with navigation and the month grids.
 *
 * Use the `components` prop to swap this component with a custom one.
 *
 * @group Components
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
function Calendar() {
    const { className, classNames, components, dataAttributes, dir, footer, hideNavigation, hideWeekdayRow, id, lang, nonce, numberOfMonths, showWeekNumber, style, styles, title } = (0, props_1.useProps)();
    const calendar = (0, calendar_1.useCalendar)();
    // Apply classnames according to props
    const cssClassNames = [classNames[UI_1.UI.Calendar]];
    if (className) {
        cssClassNames.push(className);
    }
    if (numberOfMonths > 1) {
        cssClassNames.push(classNames[UI_1.CalendarFlag.hasMultipleMonths]);
    }
    if (showWeekNumber) {
        cssClassNames.push(classNames[UI_1.CalendarFlag.hasWeekNumbers]);
    }
    if (hideWeekdayRow) {
        cssClassNames.push(classNames[UI_1.CalendarFlag.noWeekdays]);
    }
    const Nav = components?.Nav ?? Nav_1.Nav;
    const Months = components?.Months ?? Months_1.Months;
    const Month = components?.Month ?? Month_1.Month;
    const Footer = components?.Footer ?? Footer_1.Footer;
    return (react_1.default.createElement("div", { className: cssClassNames.join(" "), style: { ...styles?.[UI_1.UI.Calendar], ...style }, dir: dir, id: id, lang: lang, nonce: nonce, title: title, ...dataAttributes },
        react_1.default.createElement(Months, { className: classNames[UI_1.UI.Months], style: styles?.[UI_1.UI.Months] },
            !hideNavigation && react_1.default.createElement(Nav, null),
            calendar.months.map((month, i) => (react_1.default.createElement(Month, { "aria-labelledby": id, key: i, index: i, month: month })))),
        footer && (react_1.default.createElement(Footer, { className: classNames[UI_1.UI.Footer], style: styles?.[UI_1.UI.Footer] }, footer))));
}
exports.Calendar = Calendar;
//# sourceMappingURL=Calendar.js.map