"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Dropdown = void 0;
const react_1 = __importDefault(require("react"));
const UI_1 = require("../UI");
const props_1 = require("../contexts/props");
const Chevron_1 = require("./Chevron");
const Option_1 = require("./Option");
const Select_1 = require("./Select");
/**
 * Render a dropdown component to use in the navigation bar.
 *
 * Use the `components` prop to swap this component with a custom one.
 *
 * @group Components
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
function Dropdown(props) {
    const { options, rootClassName, className, ...selectProps } = props;
    const { classNames, components } = (0, props_1.useProps)();
    const cssClassRoot = [classNames[UI_1.UI.DropdownRoot], rootClassName].join(" ");
    const cssClassSelect = [classNames[UI_1.UI.Dropdown], className].join(" ");
    const Select = components?.Select ?? Select_1.Select;
    const Option = components?.Option ?? Option_1.Option;
    const Chevron = components?.Chevron ?? Chevron_1.Chevron;
    const selectedOption = options?.find(([value]) => value === selectProps.value);
    return (react_1.default.createElement("span", { className: cssClassRoot },
        react_1.default.createElement(Select, { className: cssClassSelect, ...selectProps }, options?.map(([value, label]) => (react_1.default.createElement(Option, { key: value, value: value }, label)))),
        react_1.default.createElement("span", { className: classNames[UI_1.UI.CaptionLabel], "aria-hidden": true },
            selectedOption?.[1],
            react_1.default.createElement(Chevron, { orientation: "down", size: 18 }))));
}
exports.Dropdown = Dropdown;
//# sourceMappingURL=Dropdown.js.map