"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MonthsDropdown = void 0;
const react_1 = __importDefault(require("react"));
const setMonth_1 = require("date-fns/setMonth");
const startOfMonth_1 = require("date-fns/startOfMonth");
const UI_1 = require("../UI");
const calendar_1 = require("../contexts/calendar");
const props_1 = require("../contexts/props");
const Dropdown_1 = require("./Dropdown");
/**
 * Render the dropdown to change the month.
 *
 * Use the `components` prop to swap this component with a custom one.
 *
 * @group Components
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
function MonthsDropdown(props) {
    const { classNames, components, disableNavigation, labels: { labelMonthDropdown } } = (0, props_1.useProps)();
    const { dropdownOptions: dropdown, goToMonth } = (0, calendar_1.useCalendar)();
    const Dropdown = components?.Dropdown ?? Dropdown_1.Dropdown;
    const handleChange = (e) => {
        const selectedMonth = Number(e.target.value);
        const month = (0, setMonth_1.setMonth)((0, startOfMonth_1.startOfMonth)(props.month.date), selectedMonth);
        goToMonth(month);
    };
    return (react_1.default.createElement(Dropdown, { "aria-label": labelMonthDropdown(), disabled: Boolean(disableNavigation), rootClassName: classNames[UI_1.UI.MonthsDropdown], options: dropdown.months, value: props.month.date.getMonth(), onChange: handleChange }));
}
exports.MonthsDropdown = MonthsDropdown;
//# sourceMappingURL=MonthsDropdown.js.map