"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Nav = void 0;
const react_1 = __importDefault(require("react"));
const UI_1 = require("../UI");
const calendar_1 = require("../contexts/calendar");
const props_1 = require("../contexts/props");
const Button_1 = require("./Button");
const Chevron_1 = require("./Chevron");
/**
 * Render the navigation buttons to change the month.
 *
 * Use the `components` prop to swap this component with a custom one.
 *
 * @group Components
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
function Nav() {
    const { classNames, styles, labels: { labelNext, labelPrevious }, locale, components, id, onNextClick, onPrevClick } = (0, props_1.useProps)();
    const calendar = (0, calendar_1.useCalendar)();
    const handlePreviousClick = () => {
        if (!calendar.previousMonth)
            return;
        calendar.goToPreviousMonth();
        onPrevClick?.(calendar.previousMonth);
    };
    const handleNextClick = () => {
        if (!calendar.nextMonth)
            return;
        calendar.goToNextMonth();
        onNextClick?.(calendar.nextMonth);
    };
    const Button = components?.Button ?? Button_1.Button;
    const Chevron = components?.Chevron ?? Chevron_1.Chevron;
    return (react_1.default.createElement("div", { role: "toolbar", className: classNames[UI_1.UI.Nav], style: styles?.[UI_1.UI.Nav] },
        react_1.default.createElement(Button, { type: "button", name: "previous-month", className: classNames[UI_1.UI.ButtonPrevious], tabIndex: calendar.previousMonth ? undefined : -1, disabled: calendar.previousMonth ? undefined : true, "aria-label": labelPrevious(calendar.previousMonth, { locale }), "aria-controls": id, onClick: handlePreviousClick },
            react_1.default.createElement(Chevron, null)),
        react_1.default.createElement(Button, { type: "button", name: "next-month", className: classNames[UI_1.UI.ButtonNext], tabIndex: calendar.nextMonth ? undefined : -1, disabled: calendar.nextMonth ? undefined : true, "aria-label": labelNext(calendar.nextMonth, { locale }), "aria-controls": id, onClick: handleNextClick },
            react_1.default.createElement(Chevron, { orientation: "right" }))));
}
exports.Nav = Nav;
//# sourceMappingURL=Nav.js.map