"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.YearsDropdown = void 0;
const react_1 = __importDefault(require("react"));
const setYear_1 = require("date-fns/setYear");
const startOfMonth_1 = require("date-fns/startOfMonth");
const UI_1 = require("../UI");
const calendar_1 = require("../contexts/calendar");
const props_1 = require("../contexts/props");
const Dropdown_1 = require("./Dropdown");
/**
 * Render the dropdown to change the year.
 *
 * Use the `components` prop to swap this component with a custom one.
 *
 * @group Components
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
function YearsDropdown(props) {
    const { classNames, components, disableNavigation, labels: { labelYearDropdown } } = (0, props_1.useProps)();
    const { dropdownOptions: dropdown, goToMonth } = (0, calendar_1.useCalendar)();
    const handleChange = (e) => {
        const month = (0, setYear_1.setYear)((0, startOfMonth_1.startOfMonth)(props.month.date), Number(e.target.value));
        goToMonth(month);
    };
    const Dropdown = components?.Dropdown ?? Dropdown_1.Dropdown;
    return (react_1.default.createElement(Dropdown, { "aria-label": labelYearDropdown(), disabled: Boolean(disableNavigation), rootClassName: classNames[UI_1.UI.YearsDropdown], options: dropdown.years, value: props.month.date.getFullYear(), onChange: handleChange }));
}
exports.YearsDropdown = YearsDropdown;
//# sourceMappingURL=YearsDropdown.js.map