"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useCalendar = exports.CalendarProvider = void 0;
const react_1 = __importDefault(require("react"));
const react_2 = require("react");
const startOfMonth_1 = require("date-fns/startOfMonth");
const getDates_1 = require("../helpers/getDates");
const getDays_1 = require("../helpers/getDays");
const getDisplayMonths_1 = require("../helpers/getDisplayMonths");
const getDropdownMonths_1 = require("../helpers/getDropdownMonths");
const getDropdownYears_1 = require("../helpers/getDropdownYears");
const getMonths_1 = require("../helpers/getMonths");
const getNextMonth_1 = require("../helpers/getNextMonth");
const getPreviousMonth_1 = require("../helpers/getPreviousMonth");
const getStartMonth_1 = require("../helpers/getStartMonth");
const getWeeks_1 = require("../helpers/getWeeks");
const useControlledValue_1 = require("../helpers/useControlledValue");
const props_1 = require("./props");
const calendarContext = (0, react_2.createContext)(undefined);
/** @private */
function CalendarProvider(providerProps) {
    const props = (0, props_1.useProps)();
    const startMonth = (0, getStartMonth_1.getStartMonth)(props);
    // The first month displayed in the calendar
    const [firstMonth, setFirstMonth] = (0, useControlledValue_1.useControlledValue)(startMonth, props.month ? (0, startOfMonth_1.startOfMonth)(props.month) : undefined);
    /** An array of the months displayed in the calendar. */
    const displayMonths = (0, getDisplayMonths_1.getDisplayMonths)(firstMonth, props);
    /** The last month displayed in the calendar. */
    const lastMonth = displayMonths[displayMonths.length - 1];
    /** An array of the dates displayed in the calendar. */
    const dates = (0, getDates_1.getDates)(displayMonths, props.toDate, props);
    /** An array of the Months displayed in the calendar. */
    const months = (0, getMonths_1.getMonths)(displayMonths, dates, props);
    /** An array of the Weeks displayed in the calendar. */
    const weeks = (0, getWeeks_1.getWeeks)(months);
    /** An array of the Days displayed in the calendar. */
    const days = (0, getDays_1.getDays)(months);
    const nextMonth = (0, getNextMonth_1.getNextMonth)(firstMonth, props);
    const previousMonth = (0, getPreviousMonth_1.getPreviousMonth)(firstMonth, props);
    function isDayDisplayed(day) {
        return weeks.some((week) => {
            return week.days.some((d) => {
                return d.isEqualTo(day);
            });
        });
    }
    function goToMonth(date) {
        if (props.disableNavigation) {
            return;
        }
        const month = (0, startOfMonth_1.startOfMonth)(date);
        setFirstMonth(month);
        props.onMonthChange?.(month);
    }
    function goToDay(day) {
        if (isDayDisplayed(day)) {
            return;
        }
        // TODO:
        // if (refDate && isBefore(date, refDate)) {
        //   console.log('date is before refDate');
        //   const month = addMonths(date, 1 + dayPicker.numberOfMonths * -1);
        //   console.log('going to month', month);
        //   goToMonth(month);
        // } else {
        //   console.log('going to month', date);
        goToMonth(day.date);
        // }
    }
    function goToNextMonth() {
        return nextMonth ? goToMonth(nextMonth) : undefined;
    }
    function goToPreviousMonth() {
        return previousMonth ? goToMonth(previousMonth) : undefined;
    }
    const isInteractive = props.mode !== "default" || props.onDayClick !== undefined;
    const calendar = {
        dates,
        months,
        weeks,
        days,
        firstMonth,
        lastMonth,
        previousMonth,
        nextMonth,
        goToMonth,
        goToNextMonth,
        goToPreviousMonth,
        goToDay,
        isInteractive,
        isDayDisplayed,
        dropdownOptions: {
            months: (0, getDropdownMonths_1.getDropdownMonths)(props),
            years: (0, getDropdownYears_1.getDropdownYears)(props)
        }
    };
    return (react_1.default.createElement(calendarContext.Provider, { value: calendar }, providerProps.children));
}
exports.CalendarProvider = CalendarProvider;
/**
 * Return the calendar state and navigation methods to navigate the calendar.
 *
 * Use this hook from the custom components passed via the `components` prop.
 *
 * @group Hooks
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
function useCalendar() {
    const context = (0, react_2.useContext)(calendarContext);
    if (!context)
        throw new Error(`useCalendar must be used within a CalendarProvider.`);
    return context;
}
exports.useCalendar = useCalendar;
//# sourceMappingURL=calendar.js.map