"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useFocus = exports.FocusProvider = void 0;
const react_1 = __importStar(require("react"));
const UI_1 = require("../UI");
const getNextFocus_1 = require("../helpers/getNextFocus");
const calendar_1 = require("./calendar");
const modifiers_1 = require("./modifiers");
const props_1 = require("./props");
const focusContext = (0, react_1.createContext)(undefined);
/** @private */
function FocusProvider({ children }) {
    const { goToDay, isDayDisplayed, days, isInteractive } = (0, calendar_1.useCalendar)();
    const { autoFocus = false, ...props } = (0, props_1.useProps)();
    const { calendarModifiers, getModifiers } = (0, modifiers_1.useModifiers)();
    const [focused, setFocused] = (0, react_1.useState)();
    const [lastFocused, setLastFocused] = (0, react_1.useState)();
    const [initiallyFocused, setInitiallyFocused] = (0, react_1.useState)(false);
    const today = calendarModifiers.today[0];
    let autoFocusTarget;
    const isValidFocusTarget = (day) => {
        return isDayDisplayed(day) && !getModifiers(day)[UI_1.DayModifier.disabled];
    };
    if (isInteractive) {
        if (focused) {
            autoFocusTarget = focused;
        }
        else if (lastFocused) {
            autoFocusTarget = lastFocused;
        }
        else if (calendarModifiers.selected[0] &&
            isValidFocusTarget(calendarModifiers.selected[0])) {
            autoFocusTarget = calendarModifiers.selected[0];
        }
        else if (today && isValidFocusTarget(today)) {
            autoFocusTarget = today;
        }
        else if (calendarModifiers.focusable[0]) {
            autoFocusTarget = calendarModifiers.focusable[0];
        }
    }
    // Focus the focus target when autoFocus is passed in
    (0, react_1.useEffect)(() => {
        if (!autoFocus)
            return;
        if (!autoFocusTarget)
            return;
        if (!initiallyFocused)
            return;
        setInitiallyFocused(true);
        setFocused(autoFocusTarget);
    }, [autoFocus, autoFocusTarget, focused, initiallyFocused]);
    function blur() {
        setLastFocused(focused);
        setFocused(undefined);
    }
    function moveFocus(moveBy, moveDir) {
        if (!focused)
            return;
        const nextFocus = (0, getNextFocus_1.getNextFocus)(moveBy, moveDir, focused, props);
        if (!nextFocus)
            return;
        goToDay(nextFocus);
        setFocused(nextFocus);
    }
    const value = {
        autoFocusTarget,
        initiallyFocused,
        focusedDay: focused,
        blur,
        focus: setFocused,
        focusDayAfter: () => moveFocus("day", "after"),
        focusDayBefore: () => moveFocus("day", "before"),
        focusWeekAfter: () => moveFocus("week", "after"),
        focusWeekBefore: () => moveFocus("week", "before"),
        focusMonthBefore: () => moveFocus("month", "before"),
        focusMonthAfter: () => moveFocus("month", "after"),
        focusYearBefore: () => moveFocus("year", "before"),
        focusYearAfter: () => moveFocus("year", "after"),
        focusStartOfWeek: () => moveFocus("startOfWeek", "before"),
        focusEndOfWeek: () => moveFocus("endOfWeek", "after")
    };
    return (react_1.default.createElement(focusContext.Provider, { value: value }, children));
}
exports.FocusProvider = FocusProvider;
/**
 * Share the focused day and the methods to move the focus.
 *
 * Use this hook from the custom components passed via the `components` prop.
 *
 * @group Hooks
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
function useFocus() {
    const context = (0, react_1.useContext)(focusContext);
    if (!context) {
        throw new Error("useFocus must be used within a FocusProvider");
    }
    return context;
}
exports.useFocus = useFocus;
//# sourceMappingURL=focus.js.map