import React from "react";
import type { ReactNode } from "react";
import type { CalendarDay } from "../classes";
import type { DayModifiers, CalendarModifiers } from "../types";
/**
 * Holds all the modifiers used in the the calendar.
 *
 * Use the Modifiers context in custom component by calling the
 * {@link useModifiers} hook.
 *
 * @group Contexts
 */
export interface ModifiersContext {
    /** Return the modifiers of the specified day. */
    getModifiers: (day: CalendarDay) => DayModifiers;
    /** A map of all the modifiers used by the calendar. */
    calendarModifiers: CalendarModifiers;
}
/** @private */
export declare function ModifiersProvider({ children }: {
    children: ReactNode;
}): React.JSX.Element;
/**
 * Access the modifiers used by the calendar.
 *
 * Use this hook from the custom components passed via the `components` prop.
 *
 * @group Hooks
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
export declare function useModifiers(): ModifiersContext;
