"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useModifiers = exports.ModifiersProvider = void 0;
const react_1 = __importStar(require("react"));
const isSameDay_1 = require("date-fns/isSameDay");
const isSameMonth_1 = require("date-fns/isSameMonth");
const dateMatchModifiers_1 = require("../utils/dateMatchModifiers");
const calendar_1 = require("./calendar");
const props_1 = require("./props");
const selection_1 = require("./selection");
const modifiersContext = (0, react_1.createContext)(undefined);
/** @private */
function ModifiersProvider({ children }) {
    const { disabled, hidden, modifiers, mode, onDayClick, showOutsideDays, today } = (0, props_1.useProps)();
    const calendar = (0, calendar_1.useCalendar)();
    const selection = (0, selection_1.useSelection)();
    /** Modifiers that are set internally. */
    const internal = {
        focused: [],
        outside: [],
        disabled: [],
        hidden: [],
        today: [],
        focusable: [],
        selected: [],
        range_start: [],
        range_middle: [],
        range_end: []
    };
    /** Custom modifiers that are coming from the `modifiers` props */
    const custom = {};
    for (const day of calendar.days) {
        const { date, displayMonth } = day;
        const isOutside = Boolean(displayMonth && !(0, isSameMonth_1.isSameMonth)(date, displayMonth));
        const isDisabled = Boolean(disabled && (0, dateMatchModifiers_1.dateMatchModifiers)(date, disabled));
        const isSelected = !isDisabled &&
            (selection.isSelected(date) ||
                Boolean(modifiers?.selected && (0, dateMatchModifiers_1.dateMatchModifiers)(date, modifiers.selected)));
        const isHidden = Boolean(hidden && (0, dateMatchModifiers_1.dateMatchModifiers)(date, hidden)) ||
            (!showOutsideDays && isOutside);
        const isInteractive = mode !== "default" || (mode === "default" && onDayClick !== undefined);
        const isFocusable = isInteractive && !isDisabled && !isHidden;
        const isToday = (0, isSameDay_1.isSameDay)(date, today);
        const isStartOfRange = selection.isStartOfRange(date);
        const isEndOfRange = selection.isEndOfRange(date);
        const isMiddleOfRange = selection.isMiddleOfRange(date);
        if (isOutside)
            internal.outside.push(day);
        if (isDisabled)
            internal.disabled.push(day);
        if (isHidden)
            internal.hidden.push(day);
        if (isFocusable)
            internal.focusable.push(day);
        if (isSelected)
            internal.selected.push(day);
        if (isToday)
            internal.today.push(day);
        if (isStartOfRange)
            internal.range_start.push(day);
        if (isEndOfRange)
            internal.range_end.push(day);
        if (isMiddleOfRange)
            internal.range_middle.push(day);
        // Now add custom modifiers
        if (modifiers) {
            Object.keys(modifiers).forEach((name) => {
                const modifierValue = modifiers?.[name];
                const isMatch = modifierValue
                    ? (0, dateMatchModifiers_1.dateMatchModifiers)(date, modifierValue)
                    : false;
                if (!isMatch)
                    return;
                if (custom[name]) {
                    custom[name].push(day);
                }
                else {
                    custom[name] = [day];
                }
            });
        }
    }
    const getModifiers = (day) => {
        const modifiers = {
            focused: false,
            disabled: false,
            focusable: false,
            hidden: false,
            outside: false,
            range_end: false,
            range_middle: false,
            range_start: false,
            selected: false,
            today: false
        };
        for (const name in internal) {
            const daysWithModifier = internal[name];
            modifiers[name] = daysWithModifier.some((d) => d === day);
        }
        for (const name in custom) {
            // This will override the internal modifiers with the same name, as intended
            modifiers[name] = custom[name].some((d) => d === day);
        }
        return modifiers;
    };
    const calendarModifiers = { ...internal, ...custom };
    const value = {
        calendarModifiers,
        getModifiers
    };
    return (react_1.default.createElement(modifiersContext.Provider, { value: value }, children));
}
exports.ModifiersProvider = ModifiersProvider;
/**
 * Access the modifiers used by the calendar.
 *
 * Use this hook from the custom components passed via the `components` prop.
 *
 * @group Hooks
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
function useModifiers() {
    const context = (0, react_1.useContext)(modifiersContext);
    if (!context)
        throw new Error(`useProps must be used within a PropsProvider.`);
    return context;
}
exports.useModifiers = useModifiers;
//# sourceMappingURL=modifiers.js.map