"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useSelection = exports.SelectionProvider = void 0;
const react_1 = __importStar(require("react"));
const addDays_1 = require("date-fns/addDays");
const differenceInCalendarDays_1 = require("date-fns/differenceInCalendarDays");
const isSameDay_1 = require("date-fns/isSameDay");
const subDays_1 = require("date-fns/subDays");
const useControlledValue_1 = require("../helpers/useControlledValue");
const addToRange_1 = require("../utils/addToRange");
const isDateInRange_1 = require("../utils/isDateInRange");
const typeguards_1 = require("../utils/typeguards");
const props_1 = require("./props");
const contextValue = {
    selected: undefined,
    setSelected: () => undefined,
    isSelected: () => false,
    isStartOfRange: () => false,
    isEndOfRange: () => false,
    isMiddleOfRange: () => false
};
const selectionContext = (0, react_1.createContext)(contextValue);
/** @private */
function SelectionProvider(providerProps) {
    const { required, min, max, onSelect, selected, defaultSelected, mode } = (0, props_1.useProps)();
    const [value, setValue] = (0, useControlledValue_1.useControlledValue)(defaultSelected ?? selected, selected);
    /** Set the selected days when in "single" mode. */
    function setSingle(date, modifiers, e) {
        let selected;
        if (modifiers.selected && !required) {
            selected = undefined;
        }
        else {
            selected = date;
        }
        setValue(selected);
        onSelect?.(selected, date, modifiers, e);
        return selected;
    }
    /** Return `true` if the given day is selected in "single" mode. */
    function isSingleSelected(date) {
        return Boolean(value && (0, isSameDay_1.isSameDay)(value, date));
    }
    /** Set the selected days when in "multiple" mode. */
    function setMulti(date, modifiers, e) {
        if (value !== undefined && !Array.isArray(value)) {
            // Not a multi select
            return;
        }
        let selected = [];
        if (modifiers.selected) {
            // Date is already selected
            if (min && value && value.length <= min) {
                // Min value reached, do nothing
                selected = value;
            }
            else {
                // Remove the date from the selection
                selected = value?.filter((day) => !(0, isSameDay_1.isSameDay)(day, date)) || [];
            }
        }
        else if (max !== undefined && value?.length === max) {
            // Max value reached, reset the selection to date
            selected = [date];
        }
        else {
            // Add the date to the selection
            selected = [...(value ?? []), date];
        }
        setValue(selected);
        onSelect?.(selected, date, modifiers, e);
        return selected;
    }
    function isMultiSelected(date) {
        if (!Array.isArray(value))
            return false;
        return Boolean(value?.some((day) => (0, isSameDay_1.isSameDay)(day, date)));
    }
    /** Set the selected days when in "range" mode. */
    function setRange(date, modifiers, e) {
        if (value !== undefined && !(0, typeguards_1.isDateRange)(value)) {
            return;
        }
        const selected = (0, addToRange_1.addToRange)(date, value);
        if (min) {
            if (selected?.from &&
                selected.to &&
                (0, differenceInCalendarDays_1.differenceInCalendarDays)(selected.to, selected.from) <= min) {
                selected.from = date;
                selected.to = undefined;
            }
        }
        if (max) {
            if (selected?.from &&
                selected.to &&
                (0, differenceInCalendarDays_1.differenceInCalendarDays)(selected.to, selected.from) + 1 > max) {
                selected.from = date;
                selected.to = undefined;
            }
        }
        setValue(selected);
        onSelect?.(selected, date, modifiers, e); // Now TypeScript knows it's a MouseEvent
        return value;
    }
    function isRangeSelected(date) {
        if (value !== undefined && !(0, typeguards_1.isDateRange)(value)) {
            // Not a range select
            return false;
        }
        return Boolean(value && (0, isDateInRange_1.isDateInRange)(date, value));
    }
    function setSelected(date, modifiers, e) {
        if (mode === "single")
            setSingle(date, modifiers, e);
        if (mode === "multiple")
            setMulti(date, modifiers, e);
        if (mode === "range")
            setRange(date, modifiers, e);
    }
    function isSelected(date) {
        if (mode === "single")
            return isSingleSelected(date);
        if (mode === "multiple")
            return isMultiSelected(date);
        if (mode === "range")
            return isRangeSelected(date);
        return false;
    }
    function isStartOfRange(date) {
        if (!(0, typeguards_1.isDateRange)(value))
            return false;
        return Boolean(value.from && (0, isSameDay_1.isSameDay)(value.from, date) && value.to);
    }
    function isEndOfRange(date) {
        if (!(0, typeguards_1.isDateRange)(value))
            return false;
        return Boolean(value.to && (0, isSameDay_1.isSameDay)(value.to, date));
    }
    function isMiddleOfRange(date) {
        if (!(0, typeguards_1.isDateRange)(value))
            return false;
        if (!value.from || !value.to)
            return false;
        return ((0, isDateInRange_1.isDateInRange)(date, {
            from: (0, addDays_1.addDays)(value.from, 1),
            to: (0, subDays_1.subDays)(value.to, 1)
        }) &&
            !isStartOfRange(date) &&
            !isEndOfRange(date));
    }
    const contextValue = {
        selected: value,
        setSelected,
        isSelected,
        isStartOfRange,
        isEndOfRange,
        isMiddleOfRange
    };
    return (react_1.default.createElement(selectionContext.Provider, { value: contextValue }, providerProps.children));
}
exports.SelectionProvider = SelectionProvider;
/**
 * Access and change the currently selected values.
 *
 * Use this hook from the custom components passed via the `components` prop.
 *
 * @group Hooks
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
function useSelection() {
    const context = (0, react_1.useContext)(selectionContext);
    if (!context) {
        throw new Error(`useSelection must be used within a SelectionProvider.`);
    }
    return context;
}
exports.useSelection = useSelection;
//# sourceMappingURL=selection.js.map