"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.daysToMonthWeeks = void 0;
const date_fns_1 = require("date-fns");
/** Return the weeks between two dates. */
function daysToMonthWeeks(fromDate, toDate, options) {
    const toWeek = options?.ISOWeek
        ? (0, date_fns_1.endOfISOWeek)(toDate)
        : (0, date_fns_1.endOfWeek)(toDate, options);
    const fromWeek = options?.ISOWeek
        ? (0, date_fns_1.startOfISOWeek)(fromDate)
        : (0, date_fns_1.startOfWeek)(fromDate, options);
    const nOfDays = (0, date_fns_1.differenceInCalendarDays)(toWeek, fromWeek);
    const days = [];
    for (let i = 0; i <= nOfDays; i++) {
        days.push((0, date_fns_1.addDays)(fromWeek, i));
    }
    const weeksInMonth = days.reduce((result, date) => {
        const weekNumber = options?.ISOWeek
            ? (0, date_fns_1.getISOWeek)(date)
            : (0, date_fns_1.getWeek)(date, options);
        const existingWeek = result.find((value) => value.weekNumber === weekNumber);
        if (existingWeek) {
            existingWeek.dates.push(date);
            return result;
        }
        result.push({
            weekNumber,
            dates: [date]
        });
        return result;
    }, []);
    return weeksInMonth;
}
exports.daysToMonthWeeks = daysToMonthWeeks;
//# sourceMappingURL=daysToMonthWeeks.js.map