"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDates = void 0;
const addDays_1 = require("date-fns/addDays");
const differenceInCalendarDays_1 = require("date-fns/differenceInCalendarDays");
const differenceInCalendarMonths_1 = require("date-fns/differenceInCalendarMonths");
const endOfISOWeek_1 = require("date-fns/endOfISOWeek");
const endOfMonth_1 = require("date-fns/endOfMonth");
const endOfWeek_1 = require("date-fns/endOfWeek");
const isAfter_1 = require("date-fns/isAfter");
const startOfISOWeek_1 = require("date-fns/startOfISOWeek");
const startOfWeek_1 = require("date-fns/startOfWeek");
/** The number of days in a month when having 6 weeks. */
const NrOfDaysWithFixedWeeks = 42;
/**
 * Return all the dates to display in the calendar.
 *
 * @param firstMonth The first month of the calendar
 * @param lastMonth The last month of the calendar
 * @param maxDate The date to end the calendar at
 * @param options Options for the calendar
 * @param options.ISOWeek Whether or not to use ISOWeek
 * @param options.fixedWeeks Whether or not to use fixed weeks
 * @param options.locale The locale to use
 * @param options.weekStartsOn The day the week starts on
 */
function getDates(displayMonths, maxDate, options) {
    const firstMonth = displayMonths[0];
    const lastMonth = displayMonths[displayMonths.length - 1];
    const { ISOWeek, fixedWeeks, locale, weekStartsOn } = options ?? {};
    const startWeekFirstDate = ISOWeek
        ? (0, startOfISOWeek_1.startOfISOWeek)(firstMonth)
        : (0, startOfWeek_1.startOfWeek)(firstMonth, {
            weekStartsOn,
            locale
        });
    const endWeekLastDate = ISOWeek
        ? (0, endOfISOWeek_1.endOfISOWeek)((0, endOfMonth_1.endOfMonth)(lastMonth))
        : (0, endOfWeek_1.endOfWeek)((0, endOfMonth_1.endOfMonth)(lastMonth), {
            weekStartsOn,
            locale
        });
    const nOfDays = (0, differenceInCalendarDays_1.differenceInCalendarDays)(endWeekLastDate, startWeekFirstDate);
    const nOfMonths = (0, differenceInCalendarMonths_1.differenceInCalendarMonths)(lastMonth, firstMonth) + 1;
    const dates = [];
    for (let i = 0; i <= nOfDays; i++) {
        const date = (0, addDays_1.addDays)(startWeekFirstDate, i);
        if (maxDate && (0, isAfter_1.isAfter)(date, maxDate)) {
            break;
        }
        dates.push(new Date(date));
    }
    // If fixed weeks is enabled, add the extra dates to the array
    const extraDates = NrOfDaysWithFixedWeeks * nOfMonths;
    if (fixedWeeks && dates.length < extraDates) {
        for (let i = 0; i < 7; i++) {
            const date = (0, addDays_1.addDays)(dates[dates.length - 1], 1);
            dates.push(new Date(date));
        }
    }
    return dates;
}
exports.getDates = getDates;
//# sourceMappingURL=getDates.js.map