"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDropdownMonths = void 0;
const addMonths_1 = require("date-fns/addMonths");
const isBefore_1 = require("date-fns/isBefore");
const startOfMonth_1 = require("date-fns/startOfMonth");
/** Return the months to show in the dropdown. */
function getDropdownMonths(props) {
    if (!props.fromDate)
        return undefined;
    if (!props.toDate)
        return undefined;
    const navStartMonth = (0, startOfMonth_1.startOfMonth)(props.fromDate);
    const navEndMonth = (0, startOfMonth_1.startOfMonth)(props.toDate);
    const months = [];
    let month = navStartMonth;
    while (months.length < 12 && (0, isBefore_1.isBefore)(month, (0, addMonths_1.addMonths)(navEndMonth, 1))) {
        months.push(month.getMonth());
        month = (0, addMonths_1.addMonths)(month, 1);
    }
    const sortedMonths = months.sort((a, b) => {
        return a - b;
    });
    const options = sortedMonths.map((m) => {
        const label = props.formatters.formatMonthDropdown(m, props.locale);
        const option = [m, label];
        return option;
    });
    return options;
}
exports.getDropdownMonths = getDropdownMonths;
//# sourceMappingURL=getDropdownMonths.js.map