"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getFirstLastMonths = void 0;
const addMonths_1 = require("date-fns/addMonths");
const differenceInCalendarMonths_1 = require("date-fns/differenceInCalendarMonths");
const startOfMonth_1 = require("date-fns/startOfMonth");
const getFromToDate_1 = require("./getFromToDate");
/**
 * Return the first and, if the navigation is constrained, last months according
 * to the props passed to DayPicker, with some extra checks for the other
 * props.
 */
function getFirstLastMonths(props) {
    const { month, defaultMonth, today, numberOfMonths = 1 } = props;
    let initialMonth = month || defaultMonth || today || new Date();
    const { fromDate, toDate } = (0, getFromToDate_1.getFromToDate)(props);
    // Fix the initialMonth if is after the to-date
    if (toDate && (0, differenceInCalendarMonths_1.differenceInCalendarMonths)(toDate, initialMonth) < 0) {
        const offset = -1 * (numberOfMonths - 1);
        initialMonth = (0, addMonths_1.addMonths)(toDate, offset);
    }
    // Fix the initialMonth if is before the from-date
    if (fromDate && (0, differenceInCalendarMonths_1.differenceInCalendarMonths)(initialMonth, fromDate) < 0) {
        initialMonth = fromDate;
    }
    return [(0, startOfMonth_1.startOfMonth)(initialMonth), toDate];
}
exports.getFirstLastMonths = getFirstLastMonths;
//# sourceMappingURL=getFirstLastMonths.js.map