"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getFromToDate = void 0;
const addYears_1 = require("date-fns/addYears");
const endOfMonth_1 = require("date-fns/endOfMonth");
const endOfYear_1 = require("date-fns/endOfYear");
const startOfDay_1 = require("date-fns/startOfDay");
const startOfMonth_1 = require("date-fns/startOfMonth");
const startOfYear_1 = require("date-fns/startOfYear");
/**
 * Return the `fromDate` and `toDate` prop values values parsing the DayPicker
 * props.
 */
function getFromToDate(props) {
    const { fromYear, toYear, fromMonth, toMonth } = props;
    let { fromDate, toDate } = props;
    const hasDropdowns = props.captionLayout?.startsWith("dropdown");
    if (fromMonth) {
        fromDate = (0, startOfMonth_1.startOfMonth)(fromMonth);
    }
    else if (fromYear) {
        fromDate = new Date(fromYear, 0, 1);
    }
    else if (!fromDate && hasDropdowns) {
        fromDate = (0, startOfYear_1.startOfYear)((0, addYears_1.addYears)(props.today ?? new Date(), -100));
    }
    if (toMonth) {
        toDate = (0, endOfMonth_1.endOfMonth)(toMonth);
    }
    else if (toYear) {
        toDate = new Date(toYear, 11, 31);
    }
    else if (!toDate && hasDropdowns) {
        toDate = (0, endOfYear_1.endOfYear)(props.today ?? new Date());
    }
    return {
        fromDate: fromDate ? (0, startOfDay_1.startOfDay)(fromDate) : undefined,
        toDate: toDate ? (0, startOfDay_1.startOfDay)(toDate) : undefined
    };
}
exports.getFromToDate = getFromToDate;
//# sourceMappingURL=getFromToDate.js.map