"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getInitialMonth = void 0;
const date_fns_1 = require("date-fns");
/** Return the initial month according to the given options. */
function getInitialMonth(context) {
    const { month, defaultMonth, today } = context;
    let initialMonth = month || defaultMonth || today || new Date();
    const { toDate, fromDate, numberOfMonths = 1 } = context;
    // Fix the initialMonth if is after the to-date
    if (toDate && (0, date_fns_1.differenceInCalendarMonths)(toDate, initialMonth) < 0) {
        const offset = -1 * (numberOfMonths - 1);
        initialMonth = (0, date_fns_1.addMonths)(toDate, offset);
    }
    // Fix the initialMonth if is before the from-date
    if (fromDate && (0, date_fns_1.differenceInCalendarMonths)(initialMonth, fromDate) < 0) {
        initialMonth = fromDate;
    }
    return (0, date_fns_1.startOfMonth)(initialMonth);
}
exports.getInitialMonth = getInitialMonth;
//# sourceMappingURL=getInitialMonth.js.map