"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getMonths = void 0;
const addDays_1 = require("date-fns/addDays");
const endOfISOWeek_1 = require("date-fns/endOfISOWeek");
const endOfMonth_1 = require("date-fns/endOfMonth");
const endOfWeek_1 = require("date-fns/endOfWeek");
const getISOWeek_1 = require("date-fns/getISOWeek");
const getWeek_1 = require("date-fns/getWeek");
const startOfISOWeek_1 = require("date-fns/startOfISOWeek");
const startOfWeek_1 = require("date-fns/startOfWeek");
const classes_1 = require("../classes");
/** Return the months to display in the calendar. */
function getMonths(
/** The months (as dates) to display in the calendar. */
displayMonths, 
/** The dates to display in the calendar. */
dates, options = {}) {
    const dayPickerMonths = displayMonths.reduce((months, month) => {
        const firstDateOfFirstWeek = options.ISOWeek
            ? (0, startOfISOWeek_1.startOfISOWeek)(month)
            : (0, startOfWeek_1.startOfWeek)(month, {
                locale: options.locale,
                weekStartsOn: options.weekStartsOn
            });
        const lastDateOfLastWeek = options.ISOWeek
            ? (0, endOfISOWeek_1.endOfISOWeek)((0, endOfMonth_1.endOfMonth)(month))
            : (0, endOfWeek_1.endOfWeek)((0, endOfMonth_1.endOfMonth)(month), {
                locale: options.locale,
                weekStartsOn: options.weekStartsOn
            });
        /** The dates to display in the month. */
        const monthDates = dates.filter((date) => {
            return date >= firstDateOfFirstWeek && date <= lastDateOfLastWeek;
        });
        if (options.fixedWeeks && monthDates.length < 42) {
            const extraDates = dates.filter((date) => {
                return (date > lastDateOfLastWeek && date <= (0, addDays_1.addDays)(lastDateOfLastWeek, 7));
            });
            monthDates.push(...extraDates);
        }
        const weeks = monthDates.reduce((weeks, date) => {
            const weekNumber = options.ISOWeek
                ? (0, getISOWeek_1.getISOWeek)(date)
                : (0, getWeek_1.getWeek)(date, {
                    locale: options.locale,
                    weekStartsOn: options.weekStartsOn,
                    firstWeekContainsDate: options.firstWeekContainsDate
                });
            const week = weeks.find((week) => week.weekNumber === weekNumber);
            const day = new classes_1.CalendarDay(date, month);
            if (!week) {
                weeks.push(new classes_1.CalendarWeek(weekNumber, [day]));
            }
            else {
                week.days.push(day);
            }
            return weeks;
        }, []);
        const dayPickerMonth = new classes_1.CalendarMonth(month, weeks);
        months.push(dayPickerMonth);
        return months;
    }, []);
    if (!options.reverseMonths) {
        return dayPickerMonths;
    }
    else {
        return dayPickerMonths.reverse();
    }
}
exports.getMonths = getMonths;
//# sourceMappingURL=getMonths.js.map