"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getNextFocus = void 0;
const classes_1 = require("../classes");
const dateMatchModifiers_1 = require("../utils/dateMatchModifiers");
const getPossibleFocusDate_1 = require("./getPossibleFocusDate");
function getNextFocus(moveBy, moveDir, 
/** The date that is currently focused. */
focused, options, attempt = 0) {
    if (attempt > 365) {
        // Limit the recursion to 365 attempts
        return undefined;
    }
    const possibleFocusDate = (0, getPossibleFocusDate_1.getPossibleFocusDate)(moveBy, moveDir, focused.date, options);
    const isDisabled = Boolean(options.disabled && (0, dateMatchModifiers_1.dateMatchModifiers)(possibleFocusDate, options.disabled));
    const isHidden = Boolean(options.hidden && (0, dateMatchModifiers_1.dateMatchModifiers)(possibleFocusDate, options.hidden));
    const targetMonth = possibleFocusDate;
    const focusDay = new classes_1.CalendarDay(possibleFocusDate, targetMonth);
    if (!isDisabled && !isHidden) {
        return focusDay;
    }
    // Recursively attempt to find the next focusable date
    return getNextFocus(moveBy, moveDir, focusDay, options, attempt + 1);
}
exports.getNextFocus = getNextFocus;
//# sourceMappingURL=getNextFocus.js.map