"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getNextMonth = void 0;
const addMonths_1 = require("date-fns/addMonths");
const differenceInCalendarMonths_1 = require("date-fns/differenceInCalendarMonths");
const startOfMonth_1 = require("date-fns/startOfMonth");
/**
 * Return the next month the user can navigate to according to the given
 * options.
 *
 * Please note that the next month is not always the next calendar month:
 *
 * - If after the `toDate` range, is `undefined`;
 * - If the navigation is paged , is the number of months displayed ahead.
 */
function getNextMonth(firstMonth, options) {
    if (options.disableNavigation) {
        return undefined;
    }
    const { toDate, pagedNavigation, numberOfMonths = 1 } = options;
    const offset = pagedNavigation ? numberOfMonths : 1;
    const month = (0, startOfMonth_1.startOfMonth)(firstMonth);
    if (!toDate) {
        return (0, addMonths_1.addMonths)(month, offset);
    }
    const monthsDiff = (0, differenceInCalendarMonths_1.differenceInCalendarMonths)(toDate, firstMonth);
    if (monthsDiff < numberOfMonths) {
        return undefined;
    }
    // Jump forward as the number of months when paged navigation
    return (0, addMonths_1.addMonths)(month, offset);
}
exports.getNextMonth = getNextMonth;
//# sourceMappingURL=getNextMonth.js.map