"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPossibleFocusDate = void 0;
const addDays_1 = require("date-fns/addDays");
const addMonths_1 = require("date-fns/addMonths");
const addWeeks_1 = require("date-fns/addWeeks");
const addYears_1 = require("date-fns/addYears");
const endOfISOWeek_1 = require("date-fns/endOfISOWeek");
const endOfWeek_1 = require("date-fns/endOfWeek");
const max_1 = require("date-fns/max");
const min_1 = require("date-fns/min");
const startOfISOWeek_1 = require("date-fns/startOfISOWeek");
const startOfWeek_1 = require("date-fns/startOfWeek");
/** Return the next date that should be focused. */
function getPossibleFocusDate(moveBy, moveDir, focusedDate, options) {
    const { weekStartsOn, fromDate, toDate, locale, ISOWeek } = options;
    const moveFns = {
        day: addDays_1.addDays,
        week: addWeeks_1.addWeeks,
        month: addMonths_1.addMonths,
        year: addYears_1.addYears,
        startOfWeek: (date) => ISOWeek
            ? (0, startOfISOWeek_1.startOfISOWeek)(date)
            : (0, startOfWeek_1.startOfWeek)(date, { locale, weekStartsOn }),
        endOfWeek: (date) => ISOWeek ? (0, endOfISOWeek_1.endOfISOWeek)(date) : (0, endOfWeek_1.endOfWeek)(date, { locale, weekStartsOn })
    };
    let nextFocusedDate = moveFns[moveBy](focusedDate, moveDir === "after" ? 1 : -1);
    if (moveDir === "before" && fromDate) {
        nextFocusedDate = (0, max_1.max)([fromDate, nextFocusedDate]);
    }
    else if (moveDir === "after" && toDate) {
        nextFocusedDate = (0, min_1.min)([toDate, nextFocusedDate]);
    }
    return nextFocusedDate;
}
exports.getPossibleFocusDate = getPossibleFocusDate;
//# sourceMappingURL=getPossibleFocusDate.js.map