"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPreviousMonth = void 0;
const addMonths_1 = require("date-fns/addMonths");
const differenceInCalendarMonths_1 = require("date-fns/differenceInCalendarMonths");
const startOfMonth_1 = require("date-fns/startOfMonth");
/**
 * Return the next previous the user can navigate to, according to the given
 * options.
 *
 * Please note that the previous month is not always the previous calendar
 * month:
 *
 * - If before the `fromDate` date, is `undefined`;
 * - If the navigation is paged, is the number of months displayed before.
 */
function getPreviousMonth(startingMonth, options) {
    if (options.disableNavigation) {
        return undefined;
    }
    const { fromDate, pagedNavigation, numberOfMonths = 1 } = options;
    const offset = pagedNavigation ? numberOfMonths : 1;
    const month = (0, startOfMonth_1.startOfMonth)(startingMonth);
    if (!fromDate) {
        return (0, addMonths_1.addMonths)(month, -offset);
    }
    const monthsDiff = (0, differenceInCalendarMonths_1.differenceInCalendarMonths)(month, fromDate);
    if (monthsDiff <= 0) {
        return undefined;
    }
    return (0, addMonths_1.addMonths)(month, -offset);
}
exports.getPreviousMonth = getPreviousMonth;
//# sourceMappingURL=getPreviousMonth.js.map