"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.addToRange = void 0;
const isAfter_1 = require("date-fns/isAfter");
const isBefore_1 = require("date-fns/isBefore");
const isSameDay_1 = require("date-fns/isSameDay");
/**
 * Add a day to an existing range.
 *
 * The returned range takes in account the `undefined` values and if the added
 * day is already present in the range.
 *
 * @group Utilities
 */
function addToRange(date, range) {
    const { from, to } = range || {};
    if (from && to) {
        if ((0, isSameDay_1.isSameDay)(to, date) && (0, isSameDay_1.isSameDay)(from, date)) {
            return undefined;
        }
        if ((0, isSameDay_1.isSameDay)(to, date)) {
            return { from: to, to: undefined };
        }
        if ((0, isSameDay_1.isSameDay)(from, date)) {
            return undefined;
        }
        if ((0, isAfter_1.isAfter)(from, date)) {
            return { from: date, to };
        }
        return { from, to: date };
    }
    if (to) {
        if ((0, isAfter_1.isAfter)(date, to)) {
            return { from: to, to: date };
        }
        return { from: date, to };
    }
    if (from) {
        if ((0, isBefore_1.isBefore)(date, from)) {
            return { from: date, to: from };
        }
        if ((0, isSameDay_1.isSameDay)(date, from)) {
            return { from: undefined, to: undefined };
        }
        return { from, to: date };
    }
    return { from: date, to: undefined };
}
exports.addToRange = addToRange;
//# sourceMappingURL=addToRange.js.map