import React from "react";
import { UI } from "../UI";
import { useProps } from "../contexts/props";
import { Chevron as DefaultChevron } from "./Chevron";
import { Option as DefaultOption } from "./Option";
import { Select as DefaultSelect } from "./Select";
/**
 * Render a dropdown component to use in the navigation bar.
 *
 * Use the `components` prop to swap this component with a custom one.
 *
 * @group Components
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
export function Dropdown(props) {
    const { options, rootClassName, className, ...selectProps } = props;
    const { classNames, components } = useProps();
    const cssClassRoot = [classNames[UI.DropdownRoot], rootClassName].join(" ");
    const cssClassSelect = [classNames[UI.Dropdown], className].join(" ");
    const Select = components?.Select ?? DefaultSelect;
    const Option = components?.Option ?? DefaultOption;
    const Chevron = components?.Chevron ?? DefaultChevron;
    const selectedOption = options?.find(([value]) => value === selectProps.value);
    return (React.createElement("span", { className: cssClassRoot },
        React.createElement(Select, { className: cssClassSelect, ...selectProps }, options?.map(([value, label]) => (React.createElement(Option, { key: value, value: value }, label)))),
        React.createElement("span", { className: classNames[UI.CaptionLabel], "aria-hidden": true },
            selectedOption?.[1],
            React.createElement(Chevron, { orientation: "down", size: 18 }))));
}
//# sourceMappingURL=Dropdown.js.map