import React from "react";
import { UI } from "../UI";
import { useProps } from "../contexts/props";
import { DropdownNav } from "./DropdownNav";
/**
 * Render the caption of a month in the calendar.
 *
 * Use the `components` prop to swap this component with a custom one.
 *
 * @group Components
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
export function MonthCaption(props) {
    const { classNames, captionLayout, formatters: { formatCaption }, labels: { labelCaption }, locale, styles } = useProps();
    return (React.createElement("div", { id: props.id, className: classNames[UI.MonthCaption], style: styles?.[UI.MonthCaption] }, captionLayout?.startsWith("dropdown") ? (React.createElement(DropdownNav, { month: props.month, index: props.index, showMonths: captionLayout === "dropdown" || captionLayout === "dropdown-months", showYears: captionLayout === "dropdown" || captionLayout === "dropdown-years" })) : (React.createElement("span", { className: classNames[UI.CaptionLabel], role: "status", "aria-live": "polite", "aria-label": labelCaption(props.month.date, { locale }) ?? undefined }, formatCaption(props.month.date, { locale })))));
}
//# sourceMappingURL=MonthCaption.js.map