import React from "react";
import { setMonth } from "date-fns/setMonth";
import { startOfMonth } from "date-fns/startOfMonth";
import { UI } from "../UI";
import { useCalendar } from "../contexts/calendar";
import { useProps } from "../contexts/props";
import { Dropdown as DefaultDropdown } from "./Dropdown";
/**
 * Render the dropdown to change the month.
 *
 * Use the `components` prop to swap this component with a custom one.
 *
 * @group Components
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
export function MonthsDropdown(props) {
    const { classNames, components, disableNavigation, labels: { labelMonthDropdown } } = useProps();
    const { dropdownOptions: dropdown, goToMonth } = useCalendar();
    const Dropdown = components?.Dropdown ?? DefaultDropdown;
    const handleChange = (e) => {
        const selectedMonth = Number(e.target.value);
        const month = setMonth(startOfMonth(props.month.date), selectedMonth);
        goToMonth(month);
    };
    return (React.createElement(Dropdown, { "aria-label": labelMonthDropdown(), disabled: Boolean(disableNavigation), rootClassName: classNames[UI.MonthsDropdown], options: dropdown.months, value: props.month.date.getMonth(), onChange: handleChange }));
}
//# sourceMappingURL=MonthsDropdown.js.map