import React from "react";
import { getUnixTime } from "date-fns/getUnixTime";
import { UI } from "../UI";
import { useProps } from "../contexts/props";
import { DayWrapper } from "./DayWrapper";
import { WeekNumber as DefaultWeekNumber } from "./WeekNumber";
/**
 * Render a row in the calendar, with the days and the week number.
 *
 * Use the `components` prop to swap this component with a custom one.
 *
 * @group Components
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
export function Week(props) {
    const { styles, classNames, showWeekNumber, components } = useProps();
    const WeekNumber = components?.WeekNumber ?? DefaultWeekNumber;
    return (React.createElement("div", { role: "row", "aria-rowindex": props["aria-rowindex"], className: classNames[UI.Week], style: styles?.[UI.Week] },
        showWeekNumber && React.createElement(WeekNumber, { week: props.week }),
        props.week.days.map((day, i) => (React.createElement(DayWrapper, { day: day, "aria-colindex": showWeekNumber ? i + 2 : i + 1, key: getUnixTime(day.date) })))));
}
//# sourceMappingURL=Week.js.map