import { ReactNode } from "react";
import type { CalendarDay } from "../classes";
export type MoveFocusBy = "day" | "week" | "startOfWeek" | "endOfWeek" | "month" | "year";
export type MoveFocusDir = "after" | "before";
/**
 * Share the focused day and the methods to move the focus.
 *
 * Access this context from the {@link useFocus} hook.
 *
 * @group Contexts
 */
export interface FocusContext {
    /** The date that is currently focused. */
    focusedDay: CalendarDay | undefined;
    /**
     * The date that is target of the focus when tabbing into the month grid. The
     * focus target is the selected date first, then the today date, then the
     * first focusable date.
     */
    autoFocusTarget: CalendarDay | undefined;
    initiallyFocused: boolean;
    /** Focus a date. */
    focus: (day: CalendarDay | undefined) => void;
    /** Blur the focused day. */
    blur: () => void;
    /** Focus the day after the focused day. */
    focusDayAfter: () => void;
    /** Focus the day before the focused day. */
    focusDayBefore: () => void;
    /** Focus the day in the week before the focused day. */
    focusWeekBefore: () => void;
    /** Focus the day in the week after the focused day. */
    focusWeekAfter: () => void;
    focusMonthBefore: () => void;
    focusMonthAfter: () => void;
    focusYearBefore: () => void;
    focusYearAfter: () => void;
    focusStartOfWeek: () => void;
    focusEndOfWeek: () => void;
}
/** @private */
export declare function FocusProvider({ children }: {
    children: ReactNode;
}): JSX.Element;
/**
 * Share the focused day and the methods to move the focus.
 *
 * Use this hook from the custom components passed via the `components` prop.
 *
 * @group Hooks
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
export declare function useFocus(): FocusContext;
