import React, { PropsWithChildren } from "react";
import type { ClassNames, DataAttributes, DayPickerProps, Formatters, Labels, Mode, PropsBase, Selected, SelectHandler } from "../types";
/**
 * Holds the props passed to the DayPicker component, with some optional props
 * set to meaningful defaults.
 *
 * Access the Props context using the {@link useProps} hook.
 *
 * @group Contexts
 */
export interface PropsContext<T extends Mode> extends PropsBase {
    classNames: ClassNames;
    /** The `data-*` attributes passed to `<DayPicker />`. */
    dataAttributes: DataAttributes;
    formatters: Formatters;
    fromDate: Date | undefined;
    id: string;
    labels: Labels;
    max: number | undefined;
    min: number | undefined;
    mode: T;
    numberOfMonths: number;
    required: boolean;
    toDate: Date | undefined;
    today: Date;
    /** The currently selected value. */
    selected: Selected<Mode> | undefined;
    /** The default selected value. */
    defaultSelected: Selected<Mode> | undefined;
    /** The function that handles the day selection. */
    onSelect: SelectHandler<Mode> | undefined;
}
/**
 * Provide the props to the DayPicker components. Must be used as root of the
 * other providers.
 *
 * @private
 */
export declare const PropsProvider: <T extends Mode>(props: PropsWithChildren<DayPickerProps<T>>) => React.JSX.Element;
/**
 * Access to the props passed to DayPicker.
 *
 * Use this hook from the custom components passed via the `components` prop.
 *
 * @group Hooks
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
export declare function useProps(): PropsContext<Mode>;
