import React, { createContext, useContext, useId } from "react";
import { getClassNames } from "../helpers/getClassNames";
import { getDataAttributes } from "../helpers/getDataAttributes";
import { getFormatters } from "../helpers/getFormatters";
import { getFromToDate } from "../helpers/getFromToDate";
import { getLabels } from "../helpers/getLabels";
const propsContext = createContext(null);
/**
 * Provide the props to the DayPicker components. Must be used as root of the
 * other providers.
 *
 * @private
 */
export const PropsProvider = (props) => {
    const reactId = useId();
    const { children, ...restProps } = props;
    const { fromDate, toDate } = getFromToDate(props);
    const context = {
        ...restProps,
        classNames: getClassNames(props.classNames),
        dataAttributes: getDataAttributes(props),
        formatters: getFormatters(props.formatters),
        fromDate,
        id: props.id ?? reactId,
        labels: getLabels(props.labels),
        required: "required" in props ? props.required ?? false : false,
        min: "min" in props ? props.min ?? undefined : undefined,
        max: "max" in props ? props.max ?? undefined : undefined,
        mode: props.mode ?? "default",
        numberOfMonths: props.numberOfMonths ?? 1,
        today: props.today ?? new Date(),
        toDate,
        selected: "selected" in props ? props.selected : undefined,
        defaultSelected: "defaultSelected" in props ? props.defaultSelected : undefined,
        onSelect: "onSelect" in props ? props.onSelect : undefined
    };
    return (React.createElement(propsContext.Provider, { value: context }, children));
};
/**
 * Access to the props passed to DayPicker.
 *
 * Use this hook from the custom components passed via the `components` prop.
 *
 * @group Hooks
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
export function useProps() {
    const context = useContext(propsContext);
    if (!context) {
        throw new Error("useDayPicker() must be used within a `<dayPickerContext.Provider/>`.");
    }
    return context;
}
//# sourceMappingURL=props.js.map